=========
Tutorials
=========

The following is a growing list of use cases that can inspire you:

.. toctree::
   :maxdepth: 1

   tutorial.simple
   tutorial.beachhead
   tutorial.cluster.web
   tutorial.master.slave.sql

In the ``demos`` directory that is coming with Plumbery you will find a
reference ``fittings.yaml`` file, plus many programs that are using Plumbery.


